@@ -13,10 +13,9 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Push;
 # ABSTRACT: Push current branch
 
-our $VERSION = '2.049';
+our $VERSION = '2.052';
 
 use Moose;
-use MooseX::Has::Sugar;
 use Types::Standard qw{ ArrayRef Str Bool };
 
 use namespace::autoclean;
@@ -34,7 +33,7 @@ sub _git_config_mapping { +{
 
 # -- attributes
 
-has remotes_must_exist => ( ro, isa=>Bool, default=>1 );
+has remotes_must_exist => ( is => 'ro', isa=>Bool, default=>1 );
 
 has push_to => (
   is   => 'ro',
@@ -88,6 +87,9 @@ sub after_release {
     my $self = shift;
     my $git  = $self->git;
 
+    # requires git 2.4.1; see "git push --follow-tags"
+    $git->config('push.followTags', 'true');
+
     # push everything on remote branch
     for my $remote ( @{ $self->push_to } ) {
       $self->log("pushing to $remote");
@@ -102,8 +104,9 @@ sub after_release {
         }
         push @remote, $branch;
       }
+      # push.followTags is set, so this also pushes the release tag that was
+      # likely just created by [Git::Tag]
       $self->log_debug($_) for $git->push( @remote );
-      $self->log_debug($_) for $git->push( { tags=>1 },  $remote[0] );
     }
 }
 
@@ -122,7 +125,7 @@ Dist::Zilla::Plugin::Git::Push - Push current branch
 
 =head1 VERSION
 
-version 2.049
+version 2.052
 
 =head1 SYNOPSIS
 
